@@ -24,9 +24,9 @@ class DeephyData:
   def save(self):
 
     if self.suffix == None:
-      fileName = self.datasetName + '.cbor'
+      fileName = self.name + '.cbor'
     else:
-      fileName = self.datasetName + "_" + self.suffix + '.cbor'
+      fileName = self.name + "_" + self.suffix + '.cbor'
 
     with open(fileName, 'wb') as fp:
       dump(asdict(self), fp)
